---
layout: post
title: AsciiDots documentation
---

AsciiDots is an esoteric programming language based on ascii art. In this language, dots, represented by periods (`.`), travel down ascii art paths and undergo operations.

---

If you are new to AsciiDots, make sure to check out the [getting started guide](./getting-started)!

